@@ -15,6 +15,7 @@ from testit_api_client.model.attachment_model import AttachmentModel
 from testit_api_client.model.attachment_model_auto_test_step_results_model import AttachmentModelAutoTestStepResultsModel
 from testit_api_client.model.attachment_put_model import AttachmentPutModel
 from testit_api_client.model.attachment_put_model_auto_test_step_results_model import AttachmentPutModelAutoTestStepResultsModel
+from testit_api_client.model.attachment_sub_get_model import AttachmentSubGetModel
 from testit_api_client.model.auto_test_average_duration_model import AutoTestAverageDurationModel
 from testit_api_client.model.auto_test_change_view_model import AutoTestChangeViewModel
 from testit_api_client.model.auto_test_change_view_model_array_work_item_changed_field_view_model import AutoTestChangeViewModelArrayWorkItemChangedFieldViewModel
@@ -27,6 +28,15 @@ from testit_api_client.model.auto_test_put_model import AutoTestPutModel
 from testit_api_client.model.auto_test_results_for_test_run_model import AutoTestResultsForTestRunModel
 from testit_api_client.model.auto_test_short_model import AutoTestShortModel
 from testit_api_client.model.auto_test_step_model import AutoTestStepModel
+from testit_api_client.model.autotest_filter_model import AutotestFilterModel
+from testit_api_client.model.autotest_historical_result_select_model import AutotestHistoricalResultSelectModel
+from testit_api_client.model.autotest_result_historical_get_model import AutotestResultHistoricalGetModel
+from testit_api_client.model.autotest_result_outcome import AutotestResultOutcome
+from testit_api_client.model.autotest_result_reason_sub_get_model import AutotestResultReasonSubGetModel
+from testit_api_client.model.autotest_select_model import AutotestSelectModel
+from testit_api_client.model.autotests_extraction_model import AutotestsExtractionModel
+from testit_api_client.model.autotests_select_model import AutotestsSelectModel
+from testit_api_client.model.available_test_result_outcome import AvailableTestResultOutcome
 from testit_api_client.model.boolean_nullable_test_plan_changed_field_view_model import BooleanNullableTestPlanChangedFieldViewModel
 from testit_api_client.model.boolean_test_plan_changed_field_view_model import BooleanTestPlanChangedFieldViewModel
 from testit_api_client.model.boolean_work_item_changed_field_view_model import BooleanWorkItemChangedFieldViewModel
@@ -36,35 +46,34 @@ from testit_api_client.model.configuration_post_model import ConfigurationPostMo
 from testit_api_client.model.configuration_put_model import ConfigurationPutModel
 from testit_api_client.model.configuration_select_model import ConfigurationSelectModel
 from testit_api_client.model.custom_attribute_change_model import CustomAttributeChangeModel
-from testit_api_client.model.custom_attribute_merge_to_global_model import CustomAttributeMergeToGlobalModel
+from testit_api_client.model.custom_attribute_get_model import CustomAttributeGetModel
 from testit_api_client.model.custom_attribute_model import CustomAttributeModel
 from testit_api_client.model.custom_attribute_option_model import CustomAttributeOptionModel
 from testit_api_client.model.custom_attribute_option_post_model import CustomAttributeOptionPostModel
 from testit_api_client.model.custom_attribute_post_model import CustomAttributePostModel
 from testit_api_client.model.custom_attribute_put_model import CustomAttributePutModel
-from testit_api_client.model.custom_attribute_replace_model import CustomAttributeReplaceModel
 from testit_api_client.model.custom_attribute_search_query_model import CustomAttributeSearchQueryModel
-from testit_api_client.model.custom_attribute_set_positions_model import CustomAttributeSetPositionsModel
 from testit_api_client.model.custom_attribute_template_model import CustomAttributeTemplateModel
 from testit_api_client.model.custom_attribute_template_post_model import CustomAttributeTemplatePostModel
 from testit_api_client.model.custom_attribute_template_put_model import CustomAttributeTemplatePutModel
 from testit_api_client.model.custom_attribute_template_search_query_model import CustomAttributeTemplateSearchQueryModel
-from testit_api_client.model.custom_attribute_template_search_response_model import CustomAttributeTemplateSearchResponseModel
 from testit_api_client.model.custom_attribute_test_plan_project_relation_put_model import CustomAttributeTestPlanProjectRelationPutModel
 from testit_api_client.model.custom_attribute_types_enum import CustomAttributeTypesEnum
-from testit_api_client.model.custom_attribute_update_model import CustomAttributeUpdateModel
 from testit_api_client.model.date_range_model import DateRangeModel
 from testit_api_client.model.date_time_range_selector_model import DateTimeRangeSelectorModel
-from testit_api_client.model.duration_range_model import DurationRangeModel
 from testit_api_client.model.external_link_model import ExternalLinkModel
 from testit_api_client.model.failure_category_model import FailureCategoryModel
 from testit_api_client.model.failure_class_model import FailureClassModel
 from testit_api_client.model.failure_class_regex_model import FailureClassRegexModel
 from testit_api_client.model.filter_model import FilterModel
-from testit_api_client.model.flaky_bulk_dto import FlakyBulkDto
+from testit_api_client.model.flaky_bulk_model import FlakyBulkModel
 from testit_api_client.model.get_xlsx_test_points_by_test_plan_model import GetXlsxTestPointsByTestPlanModel
+from testit_api_client.model.global_custom_attribute_post_model import GlobalCustomAttributePostModel
+from testit_api_client.model.global_custom_attribute_update_model import GlobalCustomAttributeUpdateModel
+from testit_api_client.model.guid_extraction_model import GuidExtractionModel
 from testit_api_client.model.guid_work_item_changed_field_view_model import GuidWorkItemChangedFieldViewModel
 from testit_api_client.model.image_resize_type import ImageResizeType
+from testit_api_client.model.int32_range_selector_model import Int32RangeSelectorModel
 from testit_api_client.model.int32_work_item_changed_field_view_model import Int32WorkItemChangedFieldViewModel
 from testit_api_client.model.int64_range_selector_model import Int64RangeSelectorModel
 from testit_api_client.model.int64_work_item_changed_field_view_model import Int64WorkItemChangedFieldViewModel
@@ -76,9 +85,11 @@ from testit_api_client.model.last_test_result_model import LastTestResultModel
 from testit_api_client.model.link_model import LinkModel
 from testit_api_client.model.link_post_model import LinkPostModel
 from testit_api_client.model.link_put_model import LinkPutModel
+from testit_api_client.model.link_sub_get_model import LinkSubGetModel
 from testit_api_client.model.link_type import LinkType
 from testit_api_client.model.no_content_result import NoContentResult
 from testit_api_client.model.notification_model import NotificationModel
+from testit_api_client.model.notification_query_filter_model import NotificationQueryFilterModel
 from testit_api_client.model.notification_type_model import NotificationTypeModel
 from testit_api_client.model.parameter_group_model import ParameterGroupModel
 from testit_api_client.model.parameter_iteration_model import ParameterIterationModel
@@ -89,16 +100,22 @@ from testit_api_client.model.parameter_short_model import ParameterShortModel
 from testit_api_client.model.period_view_model import PeriodViewModel
 from testit_api_client.model.period_view_model_test_plan_changed_field_view_model import PeriodViewModelTestPlanChangedFieldViewModel
 from testit_api_client.model.problem_details import ProblemDetails
+from testit_api_client.model.project_attributes_filter_model import ProjectAttributesFilterModel
+from testit_api_client.model.project_custom_attribute_template_get_model import ProjectCustomAttributeTemplateGetModel
+from testit_api_client.model.project_custom_attributes_templates_filter_model import ProjectCustomAttributesTemplatesFilterModel
 from testit_api_client.model.project_export_query_model import ProjectExportQueryModel
 from testit_api_client.model.project_export_with_test_plans_post_model import ProjectExportWithTestPlansPostModel
 from testit_api_client.model.project_model import ProjectModel
 from testit_api_client.model.project_post_model import ProjectPostModel
 from testit_api_client.model.project_put_model import ProjectPutModel
-from testit_api_client.model.project_select_model import ProjectSelectModel
 from testit_api_client.model.project_shortest_model import ProjectShortestModel
+from testit_api_client.model.projects_filter_model import ProjectsFilterModel
 from testit_api_client.model.public_test_point_model import PublicTestPointModel
 from testit_api_client.model.public_test_run_model import PublicTestRunModel
 from testit_api_client.model.request_type_model import RequestTypeModel
+from testit_api_client.model.search_auto_tests_query_includes_model import SearchAutoTestsQueryIncludesModel
+from testit_api_client.model.search_custom_attribute_template_get_model import SearchCustomAttributeTemplateGetModel
+from testit_api_client.model.search_webhooks_query_model import SearchWebhooksQueryModel
 from testit_api_client.model.section_model import SectionModel
 from testit_api_client.model.section_move_model import SectionMoveModel
 from testit_api_client.model.section_post_model import SectionPostModel
@@ -108,6 +125,9 @@ from testit_api_client.model.section_with_steps_model import SectionWithStepsMod
 from testit_api_client.model.shared_step_change_view_model import SharedStepChangeViewModel
 from testit_api_client.model.shared_step_model import SharedStepModel
 from testit_api_client.model.shared_step_reference_model import SharedStepReferenceModel
+from testit_api_client.model.shared_step_reference_section_model import SharedStepReferenceSectionModel
+from testit_api_client.model.shared_step_reference_sections_query_filter_model import SharedStepReferenceSectionsQueryFilterModel
+from testit_api_client.model.shared_step_references_query_filter_model import SharedStepReferencesQueryFilterModel
 from testit_api_client.model.shared_step_result_model import SharedStepResultModel
 from testit_api_client.model.short_configuration import ShortConfiguration
 from testit_api_client.model.step_comment_model import StepCommentModel
@@ -138,9 +158,9 @@ from testit_api_client.model.test_point_analytic_result import TestPointAnalytic
 from testit_api_client.model.test_point_by_test_suite_model import TestPointByTestSuiteModel
 from testit_api_client.model.test_point_change_view_model import TestPointChangeViewModel
 from testit_api_client.model.test_point_change_view_model_test_plan_changed_field_view_model import TestPointChangeViewModelTestPlanChangedFieldViewModel
+from testit_api_client.model.test_point_filter_model import TestPointFilterModel
 from testit_api_client.model.test_point_put_model import TestPointPutModel
 from testit_api_client.model.test_point_result_model import TestPointResultModel
-from testit_api_client.model.test_point_select_model import TestPointSelectModel
 from testit_api_client.model.test_point_selector import TestPointSelector
 from testit_api_client.model.test_point_short_get_model import TestPointShortGetModel
 from testit_api_client.model.test_point_short_model import TestPointShortModel
@@ -149,24 +169,34 @@ from testit_api_client.model.test_point_with_last_result_model import TestPointW
 from testit_api_client.model.test_result_change_view_model import TestResultChangeViewModel
 from testit_api_client.model.test_result_change_view_model_test_plan_changed_field_view_model import TestResultChangeViewModelTestPlanChangedFieldViewModel
 from testit_api_client.model.test_result_chronology_model import TestResultChronologyModel
-from testit_api_client.model.test_result_create_model import TestResultCreateModel
 from testit_api_client.model.test_result_history_report_model import TestResultHistoryReportModel
-from testit_api_client.model.test_result_link_request_post_model import TestResultLinkRequestPostModel
 from testit_api_client.model.test_result_model import TestResultModel
+from testit_api_client.model.test_result_outcome import TestResultOutcome
+from testit_api_client.model.test_result_short_get_model import TestResultShortGetModel
 from testit_api_client.model.test_result_short_model import TestResultShortModel
 from testit_api_client.model.test_result_step_comment_put_model import TestResultStepCommentPutModel
+from testit_api_client.model.test_result_update_model import TestResultUpdateModel
 from testit_api_client.model.test_result_v2_get_model import TestResultV2GetModel
 from testit_api_client.model.test_result_v2_short_model import TestResultV2ShortModel
+from testit_api_client.model.test_results_filter_model import TestResultsFilterModel
+from testit_api_client.model.test_results_local_filter_model import TestResultsLocalFilterModel
+from testit_api_client.model.test_results_statistics_get_model import TestResultsStatisticsGetModel
 from testit_api_client.model.test_run_analytic_result_model import TestRunAnalyticResultModel
 from testit_api_client.model.test_run_fill_by_auto_tests_post_model import TestRunFillByAutoTestsPostModel
 from testit_api_client.model.test_run_fill_by_configurations_post_model import TestRunFillByConfigurationsPostModel
 from testit_api_client.model.test_run_fill_by_work_items_post_model import TestRunFillByWorkItemsPostModel
+from testit_api_client.model.test_run_filter_model import TestRunFilterModel
 from testit_api_client.model.test_run_group_by_failure_class_model import TestRunGroupByFailureClassModel
 from testit_api_client.model.test_run_group_by_status_model import TestRunGroupByStatusModel
 from testit_api_client.model.test_run_model import TestRunModel
 from testit_api_client.model.test_run_search_query_model import TestRunSearchQueryModel
+from testit_api_client.model.test_run_short_get_model import TestRunShortGetModel
 from testit_api_client.model.test_run_short_model import TestRunShortModel
-from testit_api_client.model.test_run_state_type_model import TestRunStateTypeModel
+from testit_api_client.model.test_run_state import TestRunState
+from testit_api_client.model.test_run_statistics_error_categories_get_model import TestRunStatisticsErrorCategoriesGetModel
+from testit_api_client.model.test_run_statistics_statuses_get_model import TestRunStatisticsStatusesGetModel
+from testit_api_client.model.test_run_test_results_partial_bulk_set_model import TestRunTestResultsPartialBulkSetModel
+from testit_api_client.model.test_run_test_results_select_model import TestRunTestResultsSelectModel
 from testit_api_client.model.test_run_v2_get_model import TestRunV2GetModel
 from testit_api_client.model.test_run_v2_post_short_model import TestRunV2PostShortModel
 from testit_api_client.model.test_run_v2_put_model import TestRunV2PutModel
@@ -178,7 +208,6 @@ from testit_api_client.model.test_suite_v2_put_model import TestSuiteV2PutModel
 from testit_api_client.model.test_suite_v2_tree_model import TestSuiteV2TreeModel
 from testit_api_client.model.test_suite_with_children_model import TestSuiteWithChildrenModel
 from testit_api_client.model.test_suite_work_items_search_model import TestSuiteWorkItemsSearchModel
-from testit_api_client.model.use_test_result_link_request_post_model import UseTestResultLinkRequestPostModel
 from testit_api_client.model.user_rank_model import UserRankModel
 from testit_api_client.model.user_with_rank_model import UserWithRankModel
 from testit_api_client.model.validate_anti_forgery_token_attribute import ValidateAntiForgeryTokenAttribute
@@ -195,7 +224,6 @@ from testit_api_client.model.work_item_comment_model import WorkItemCommentModel
 from testit_api_client.model.work_item_comment_post_model import WorkItemCommentPostModel
 from testit_api_client.model.work_item_comment_put_model import WorkItemCommentPutModel
 from testit_api_client.model.work_item_entity_types import WorkItemEntityTypes
-from testit_api_client.model.work_item_extraction_model import WorkItemExtractionModel
 from testit_api_client.model.work_item_filter_model import WorkItemFilterModel
 from testit_api_client.model.work_item_id_model import WorkItemIdModel
 from testit_api_client.model.work_item_identifier_model import WorkItemIdentifierModel
@@ -214,3 +242,4 @@ from testit_api_client.model.work_item_states import WorkItemStates
 from testit_api_client.model.work_item_step_change_view_model import WorkItemStepChangeViewModel
 from testit_api_client.model.work_item_step_change_view_model_array_work_item_changed_field_view_model import WorkItemStepChangeViewModelArrayWorkItemChangedFieldViewModel
 from testit_api_client.model.work_item_version_model import WorkItemVersionModel
+from testit_api_client.model.work_items_extraction_model import WorkItemsExtractionModel
